Package: QFeatures
Title: Quantitative features for mass spectrometry data
Version: 1.22.0
Authors@R: c(person("Laurent", "Gatto",
                    email = "laurent.gatto@uclouvain.be",
                    comment = c(ORCID = "0000-0002-1520-2268"),
                    role = c("aut", "cre")),
             person("Christophe", "Vanderaa",
                    email = "christophe.vanderaa@uclouvain.be",
                    comment = c(ORCID = "0000-0001-7443-5427"),
                    role = "aut"),
             person("Karolína", "Kryštofová",
                    comment = c(ORCID = "0009-0004-2896-2188"),
                    role = "ctb"),
             person("Léopold", "Guyot",
                     email = "leopold.guyot@uclouvain.be",
                     role = "ctb"))
Description: The QFeatures infrastructure enables the management and
   processing of quantitative features for high-throughput mass
   spectrometry assays. It provides a familiar Bioconductor user
   experience to manages quantitative data across different assay
   levels (such as peptide spectrum matches, peptides and proteins) in
   a coherent and tractable format.
Depends: R (>= 4.1), MultiAssayExperiment (>= 1.33.6)
Imports: methods, stats, utils, S4Vectors, IRanges,
        SummarizedExperiment, BiocGenerics (>= 0.53.4), ProtGenerics
        (>= 1.35.1), AnnotationFilter, lazyeval, Biobase, MsCoreUtils
        (>= 1.7.2), igraph, grDevices, plotly, tidyr, tidyselect,
        reshape2
Suggests: SingleCellExperiment, MsDataHub (>= 1.11.5), arrow, Matrix,
        HDF5Array, msdata, ggplot2, gplots, dplyr, limma, DT, shiny,
        shinydashboard, testthat, knitr, BiocStyle, rmarkdown, vsn,
        preprocessCore, matrixStats, imputeLCMD, pcaMethods, impute,
        norm, ComplexHeatmap
biocViews: Infrastructure, MassSpectrometry, Proteomics, Metabolomics
License: Artistic-2.0
Encoding: UTF-8
VignetteBuilder: knitr
BugReports: https://github.com/rformassspectrometry/QFeatures/issues
URL: https://rformassspectrometry.github.io/QFeatures
Collate: 'AllGenerics.R' 'AssayLinks.R' 'QFeatures-class.R'
        'QFeatures-functions.R' 'QFeatures-longForm.R'
        'QFeatures-processing.R' 'QFeatures-filter.R'
        'QFeatures-missing-data.R' 'QFeatures-aggregation.R'
        'QFeatures-imputation.R' 'QFeatures-join.R'
        'QFeatures-validity.R' 'SummarizedExperiment-methods.R'
        'subsetBy-methods.R' 'readQFeatures.R'
        'readQFeaturesFromDIANN.R' 'data.R' 'reduce.R' 'utils.R'
        'display.R'
Roxygen: list(markdown=TRUE)
RoxygenNote: 7.3.3
git_url: https://git.bioconductor.org/packages/QFeatures
git_branch: RELEASE_3_23
git_last_commit: b996204
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:12:28 UTC; biocbuild
Author: Laurent Gatto [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1520-2268>),
  Christophe Vanderaa [aut] (ORCID:
    <https://orcid.org/0000-0001-7443-5427>),
  Karolína Kryštofová [ctb] (ORCID:
    <https://orcid.org/0009-0004-2896-2188>),
  Léopold Guyot [ctb]
Maintainer: Laurent Gatto <laurent.gatto@uclouvain.be>
Built: R 4.6.0; ; 2026-04-29 04:55:43 UTC; unix
