# Generated by roxygen2: do not edit by hand

S3method(plot,QFeatures)
export("adjacencyMatrix<-")
export(AssayLink)
export(AssayLinks)
export(QFeatures)
export(VariableFilter)
export(addAssay)
export(addAssayLink)
export(addAssayLinkOneToOne)
export(assayLink)
export(assayLinks)
export(countUniqueFeatures)
export(createPrecursorId)
export(display)
export(dropEmptyAssays)
export(expandDataFrame)
export(getQFeaturesType)
export(isDuplicated)
export(joinAssays)
export(longFormat)
export(rbindRowData)
export(readQFeatures)
export(readQFeaturesFromDIANN)
export(readSummarizedExperiment)
export(reduceDataFrame)
export(removeAssay)
export(replaceAssay)
export(replaceColnames)
export(rowDataNames)
export(selectRowData)
export(setQFeaturesType)
export(unfoldDataFrame)
export(validQFeaturesTypes)
exportClasses(AssayLink)
exportClasses(AssayLinks)
exportClasses(CharacterVariableFilter)
exportClasses(NumericVariableFilter)
exportClasses(QFeatures)
exportMethods("[")
exportMethods("[[<-")
exportMethods("names<-")
exportMethods("rowData<-")
exportMethods(adjacencyMatrix)
exportMethods(aggcounts)
exportMethods(aggregateFeatures)
exportMethods(c)
exportMethods(coerce)
exportMethods(dims)
exportMethods(filterFeatures)
exportMethods(filterNA)
exportMethods(impute)
exportMethods(infIsNA)
exportMethods(logTransform)
exportMethods(longForm)
exportMethods(nNA)
exportMethods(ncols)
exportMethods(normalize)
exportMethods(nrows)
exportMethods(scaleTransform)
exportMethods(show)
exportMethods(subsetByFeature)
exportMethods(sweep)
exportMethods(updateObject)
exportMethods(zeroIsNA)
import(AnnotationFilter)
import(IRanges)
import(MultiAssayExperiment)
import(ProtGenerics)
import(S4Vectors)
import(SummarizedExperiment)
importFrom(Biobase,fData)
importFrom(BiocGenerics,dims)
importFrom(BiocGenerics,do.call)
importFrom(BiocGenerics,longForm)
importFrom(BiocGenerics,ncols)
importFrom(BiocGenerics,normalize)
importFrom(BiocGenerics,nrows)
importFrom(MsCoreUtils,aggregate_by_matrix)
importFrom(MsCoreUtils,aggregate_by_vector)
importFrom(MsCoreUtils,colCounts)
importFrom(MsCoreUtils,impute_matrix)
importFrom(MsCoreUtils,robustSummary)
importFrom(MultiAssayExperiment,longForm)
importFrom(ProtGenerics,adjacencyMatrix)
importFrom(grDevices,rgb)
importFrom(igraph,V)
importFrom(igraph,add_edges)
importFrom(igraph,get.edgelist)
importFrom(igraph,layout_as_tree)
importFrom(igraph,make_graph)
importFrom(igraph,plot.igraph)
importFrom(lazyeval,f_eval)
importFrom(methods,as)
importFrom(methods,callNextMethod)
importFrom(methods,extends)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,slot)
importFrom(methods,validObject)
importFrom(reshape2,melt)
importFrom(stats,heatmap)
importFrom(tidyr,pivot_wider)
importFrom(tidyselect,all_of)
importFrom(utils,read.csv)
importMethodsFrom(ProtGenerics,filterFeatures)
